FilterParserError

Enum FilterParserError 

#[non_exhaustive]
pub enum FilterParserError {
Show 14 variants Io(IOError), Network(HttpClientError), EmptyIf, UnbalancedElse, UnbalancedEndIf, UnbalancedIf, RecursiveInclusion, StackIsCorrupted, SchemeIsIncorrect(String), InvalidBooleanExpression, InvalidChecksum(String, String), NoContent, FilterContentIsLikelyNotAFilter, Other(String),
}
Errors for filter parser module

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Io(IOError)

Proxy value for std::io::Error



Network(HttpClientError)

Proxy value for http client errors



EmptyIf

Token !#if has no condition expression after that



UnbalancedElse

At least one !#else directive is redundant, because it is not balanced with the !#if directive.



UnbalancedEndIf

At least one !#endif directive is redundant, because it is not balanced with the !#if directive.



UnbalancedIf

We’ve found unbalanced if/else/endif expressions after compiling the filter



RecursiveInclusion

Recursive filter inclusion detected



StackIsCorrupted

Stack is corrupted. This is internal error



SchemeIsIncorrect(String)

Scheme problems marker



InvalidBooleanExpression

Expression passed into !#endif is invalid



InvalidChecksum(String, String)

Calculated invalid checksum



NoContent

Next patch is not compiled yet. So the remote file is empty



FilterContentIsLikelyNotAFilter

When filter’s body is not valid filters body by parser’s heuristics



Other(String)

Other errors